summaryrefslogtreecommitdiffstats
path: root/kpf/src/Server.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpf/src/Server.h')
-rw-r--r--kpf/src/Server.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kpf/src/Server.h b/kpf/src/Server.h
index c83f4a3d..2e332801 100644
--- a/kpf/src/Server.h
+++ b/kpf/src/Server.h
@@ -37,11 +37,12 @@ namespace KPF
/**
* Converses with a remote client. Handles requests and generates responses.
* Bandwidth is controlled by parent (WebServer).
*/
- class Server : public QObject
+ class Server : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -60,14 +61,14 @@ namespace KPF
*
* @param socket The system's socket device, used for communication.
*
* @param parent A WebServer, which will manage this Server.
*/
Server
(
const TQString & dir,
bool followSymlinks,
int socket,
- WebServer * parent
+ WebServer * tqparent
);
/**
@@ -37,11 +37,12 @@ namespace KPF
/**
* Converses with a remote client. Handles requests and generates responses.
- * Bandwidth is controlled by parent (WebServer).
+ * Bandwidth is controlled by tqparent (WebServer).
*/
@@ -60,14 +61,14 @@ namespace KPF
* @param socket The system's socket device, used for communication.
*
- * @param parent A WebServer, which will manage this Server.
+ * @param tqparent A WebServer, which will manage this Server.
*/
Server